#!/usr/bin/env python
"""
Rich Logger - A beautiful and feature-rich logging package using Rich library.
"""
import os
from pathlib import Path
import traceback

def get_version():
    """
    Get the version of the ddf module.
    Version is taken from the __version__.py file if it exists.
    The content of __version__.py should be:
    version = "0.33"
    """
    try:
        version_file = Path(__file__).parent / "__version__.py"
        if version_file.is_file():
            with open(version_file, "r") as f:
                for line in f:
                    if line.strip().startswith("version"):
                        parts = line.split("=")
                        if len(parts) == 2:
                            return parts[1].strip().strip('"').strip("'")
    except Exception as e:
        if os.getenv('TRACEBACK') and os.getenv('TRACEBACK') in ['1', 'true', 'True']:
            print(traceback.format_exc())
        else:
            print(f"ERROR: {e}")

    return "0.0.0"
    
__version__ = get_version()
__author__ = "Hadi Cahyadi"
__email__ = "cumulus13@gmail.com"

from .logger import (
    setup_logging,
    setup_logging_custom,
    get_def,
    CustomFormatter,
    CustomRichFormatter,
    _add_custom_level_method,
    EMERGENCY_LEVEL,
    FATAL_LEVEL,
    CRITICAL_LEVEL,
    ALERT_LEVEL,
    NOTICE_LEVEL,
    RICH_AVAILABLE,
    test,
    RichColorLogFormatter,
    RichColorLogHandler,
    RichColorLogHandler2,
    AnsiLogHandler,
    ColorSupport,
    Check,
    Colors,
    PerformanceTracker,
    performance_monitor,
    Icon,
    IconFilter,
    CustomLogger,
    RabbitMQHandler,
    KafkaHandler,
    ZeroMQHandler,
    SyslogHandler,
    DatabaseHandler,
    getLoggerSimple,
    test,
    test_brokers,
    test_lexer,
    run_test
)

__all__ = [
    "setup_logging",
    "setup_logging_custom", 
    "get_def",
    "CustomFormatter",
    "CustomRichFormatter",
    "EMERGENCY_LEVEL",
    "FATAL_LEVEL", 
    "CRITICAL_LEVEL",
    "ALERT_LEVEL",
    "NOTICE_LEVEL"
    "RICH_AVAILABLE",
    "_add_custom_level_method",
    "test",
    "RichColorLogFormatter",
    "RichColorLogHandler",
    "RichColorLogHandler2",
    "AnsiLogHandler",
    "ColorSupport",
    "Check",
    "Colors",
    "PerformanceTracker",
    "performance_monitor",
    "Icon",
    "IconFilter",
    "CustomLogger",
    "RabbitMQHandler",
    "KafkaHandler",
    "ZeroMQHandler",
    "SyslogHandler",
    "DatabaseHandler",
    "getLoggerSimple",
    "test",
    "test_brokers",
    "test_lexer",
    "run_test"
]



def test():
	from richcolorlog import setup_logging, AnsiLogHandler
	import os

	HAS_RICH=False
	try:
	    from rich.console import Console
	    from rich.panel import Panel
	    from rich.align import Align
	    console = Console()
	    HAS_RICH=True
	except:
	    # print("THIS TEST for 'rich' module installed !, please install first `pip install rich`")
	    # sys.exit()
	    pass

	if HAS_RICH:
	    console.print(Panel(Align("[bold #00FFFF]TEST LOGGING[/] with [bold #FFFF00]RichColorLog[/] [bold #AAAAFF](setup_logging)[/]", "center"), expand=True, border_style="green"))

	    console.rule(f"INFO: default")
	    logger= setup_logging()
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    # console.rule("end")
	    console.rule("end")
	    console.print()

	    console.rule("INFO: show_path=False")
	    logger= setup_logging(show_path=False)
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("INFO: show_icon=False")
	    logger= setup_logging(show_icon=False, show_path=False)
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("INFO: icon_first=False")
	    logger= setup_logging(icon_first=False, show_path=False)
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("ERROR: default, level_in_message=False")
	    logger= setup_logging(level_in_message=False)
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("ERROR: show_path=False, level_in_message=False")
	    logger= setup_logging(show_path=False, level_in_message=False)
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("ERROR: show_icon=False, level_in_message=False")
	    logger= setup_logging(show_icon=False, show_path=False, level_in_message=False)
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("ERROR: icon_first=False, level_in_message=False")
	    logger= setup_logging(icon_first=False, show_path=False, level_in_message=False)
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("show_path=False, level_in_message=False")
	    logger = setup_logging(show_path=False, level_in_message=False)
	            
	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.fatal("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("show_background=False, show_path=False, level_in_message=False")
	    logger = setup_logging(show_background=False, show_path=False, level_in_message=False)

	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("end")
	    console.print()

	    console.rule("icon_first=False, show_path=False, level_in_message=False")
	    logger = setup_logging(show_path=False, icon_first=False)
	            
	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.fatal("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    console.rule("end")
	    console.print()

	    console.rule("show_background=False, icon_first=False, show_path=False, level_in_message=False")
	    logger = setup_logging(show_background=False, show_path=False, icon_first=False)

	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("end")
	    console.print()

	    console.rule("show_background=False, icon_first=False, show_path=True, level_in_message=False")
	    logger = setup_logging(show_background=False, show_path=True, icon_first=False)

	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("end")
	    console.print()

	    console.rule("show_background=True, icon_first=False, show_path=True, level_in_message=True")
	    logger = setup_logging(show_background=True, show_path=True, icon_first=False, level_in_message=True)

	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("end")
	    console.print()

	    import logging
	    console.rule("⭐INHERITANCE⭐", characters="🦆")
	    console.print("\n\n")

	    logger = logging.getLogger("INHERITANCE")
	    from richcolorlog import RichColorLogHandler
	    handler = RichColorLogHandler()
	    logger.handlers.clear()
	    logger.addHandler(handler)
	    logger.propagate = False

	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("⭐INHERITANCE⭐ debug_color=#FFAA00", characters="🦆")
	    handler = RichColorLogHandler(debug_color="#FFAA00")
	    logger.handlers.clear()
	    logger.addHandler(handler)
	    logger.propagate = False
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    handler = RichColorLogHandler()
	    logger.handlers.clear()
	    logger.addHandler(handler)
	    logger.propagate = False
	    logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("end")
	    console.print()

	    console.rule("⭐INHERITANCE⭐show_path=False, show_path=False", characters="🌽")
	    console.print("\n\n")

	    logger = logging.getLogger("INHERITANCE")
	    from richcolorlog import RichColorLogHandler
	    handler = RichColorLogHandler(show_path=False)
	    logger.handlers.clear()
	    logger.addHandler(handler)
	    logger.propagate = False

	    logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    console.rule("⭐INHERITANCE⭐ debug_color=#FFAA00, show_path=False", characters="🌽")
	    handler = RichColorLogHandler(debug_color="#FFAA00", show_path=False)
	    logger.handlers.clear()
	    logger.addHandler(handler)
	    logger.propagate = False
	    logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	    handler = RichColorLogHandler(show_path=False)
	    logger.handlers.clear()
	    logger.addHandler(handler)
	    logger.propagate = False
	    logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	#==========================================================================================

	console.print(Panel(Align("[bold #00FFFF]TEST LOGGING[/] with [bold #FFFF00]AnsiLogHandler[/] [bold #AAAAFF](setup_logging)[/]", "center"), expand=True, border_style="green"))

	console.rule(f"INFO: default")
	logger= setup_logging(HANDLER=AnsiLogHandler)
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	# console.rule("end")
	console.rule("end")
	console.print()

	console.rule("INFO: show_path=False")
	logger= setup_logging(show_path=False, HANDLER=AnsiLogHandler)
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("INFO: show_icon=False")
	logger= setup_logging(show_icon=False, show_path=False, HANDLER=AnsiLogHandler)
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("INFO: icon_first=False")
	logger= setup_logging(icon_first=False, show_path=False, HANDLER=AnsiLogHandler)
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("ERROR: default, level_in_message=False")
	logger= setup_logging(level_in_message=False, HANDLER=AnsiLogHandler)
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("ERROR: show_path=False, level_in_message=False")
	logger= setup_logging(show_path=False, level_in_message=False, HANDLER=AnsiLogHandler)
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("ERROR: show_icon=False, level_in_message=False")
	logger= setup_logging(show_icon=False, show_path=False, level_in_message=False, HANDLER=AnsiLogHandler)
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("ERROR: icon_first=False, level_in_message=False")
	logger= setup_logging(icon_first=False, show_path=False, level_in_message=False, HANDLER=AnsiLogHandler)
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("show_path=False, level_in_message=False")
	logger = setup_logging(show_path=False, level_in_message=False, HANDLER=AnsiLogHandler)
	        
	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.fatal("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("show_background=False, show_path=False, level_in_message=False")
	logger = setup_logging(show_background=False, show_path=False, level_in_message=False, HANDLER=AnsiLogHandler)

	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("end")
	console.print()

	console.rule("icon_first=False, show_path=False, level_in_message=False")
	logger = setup_logging(show_path=False, icon_first=False, HANDLER=AnsiLogHandler)
	        
	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.fatal("This is a debug message - will RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	console.rule("end")
	console.print()

	console.rule("show_background=False, icon_first=False, show_path=False, level_in_message=False")
	logger = setup_logging(show_background=False, show_path=False, icon_first=False, HANDLER=AnsiLogHandler)

	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("end")
	console.print()

	console.rule("show_background=False, icon_first=False, show_path=True, level_in_message=False")
	logger = setup_logging(show_background=False, show_path=True, icon_first=False, HANDLER=AnsiLogHandler)

	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("end")
	console.print()

	console.rule("show_background=True, icon_first=False, show_path=True, level_in_message=True")
	logger = setup_logging(show_background=True, show_path=True, icon_first=False, level_in_message=True, HANDLER=AnsiLogHandler)

	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("end")
	console.print()

	import logging
	console.rule("⭐INHERITANCE⭐", characters="🦆")
	console.print("\n\n")

	logger = logging.getLogger("INHERITANCE")
	from richcolorlog import AnsiLogHandler
	handler = AnsiLogHandler()
	logger.handlers.clear()
	logger.addHandler(handler)
	logger.propagate = False

	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("⭐INHERITANCE⭐ debug_color=#FFAA00", characters="🦆")
	handler = AnsiLogHandler(debug_color="#FFAA00")
	logger.handlers.clear()
	logger.addHandler(handler)
	logger.propagate = False
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	handler = AnsiLogHandler()
	logger.handlers.clear()
	logger.addHandler(handler)
	logger.propagate = False
	logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("end")
	console.print()

	console.rule("⭐INHERITANCE⭐show_path=False, show_path=False", characters="🌽")
	console.print("\n\n")

	logger = logging.getLogger("INHERITANCE")
	from richcolorlog import AnsiLogHandler
	handler = AnsiLogHandler(show_path=False)
	logger.handlers.clear()
	logger.addHandler(handler)
	logger.propagate = False

	logger.emergency("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.alert("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.critical("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.error("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.warning("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.notice("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	console.rule("⭐INHERITANCE⭐ debug_color='\x1b[38;2;255;170;0m', show_path=False", characters="🌽")
	handler = AnsiLogHandler(debug_color="\x1b[38;2;255;170;0m", show_path=False)
	logger.handlers.clear()
	logger.addHandler(handler)
	logger.propagate = False
	logger.debug("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")

	handler = AnsiLogHandler(show_path=False)
	logger.handlers.clear()
	logger.addHandler(handler)
	logger.propagate = False
	logger.fatal("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")


	# for ansi color easy use with make_colors.getSort() `pip install make_colors` (see README.)

if __name__ == '__main__':
	test()





from logger import getLogger, setup_logging

logger = getLogger('myapp')

# Log with syntax highlighting
code = """
def hello():
    print("Hello World")
"""

logger.info(code, lexer='python')  # Will be highlighted as a python code
logger.debug("SELECT * FROM users", lexer='sql')  # Will be highlighted as SQL
logger.debug("This is a debug message")




from richcolorlog import setup_logging
import os
from rich.console import Console
from rich.panel import Panel
from rich.align import Align
console = Console()

console.print(Panel(Align("[bold #00FFFF]TEST LOGGING[/] with [bold #FFFF00]RichColorLog[/] [bold #AAAAFF](setup_logging)[/]", "center"), expand=True, border_style="green"))

console.rule(f"INFO: default")
logger= setup_logging(show_type=True)
logger.info("RGBME v0.13.2 - 128x64 Matrix | 1x1 Chain | 12px per LED (REAL) | BrowserAdapter")


import os
import sys
import platform
import ctypes


class SafeDict(dict):
    """Dictionary yang mengembalikan string kosong untuk key yang tidak ada."""
    def __missing__(self, key):
        return ''


class ColorSupport:
    TRUECOLOR = "truecolor"
    COLOR_256 = "256color"
    BASIC = "basic"
    NONE = "none"


class Check:
    """Auto-detect terminal color support across all major OS."""

    def __new__(cls, force: str | None = None):
        """Return detected color mode immediately (not an instance)."""
        return cls.detect_color_support(force)

    # --- Environment checks ---
    @staticmethod
    def _check_env_truecolor() -> bool:
        colorterm = (os.getenv("COLORTERM") or "").lower()
        if "truecolor" in colorterm or "24bit" in colorterm:
            return True
        if os.getenv("WT_SESSION"):  # Windows Terminal
            return True
        return False

    # --- curses terminfo (Unix-like only) ---
    @staticmethod
    def _curses_colors() -> int:
        try:
            import curses
            curses.setupterm()
            n = curses.tigetnum("colors")
            if isinstance(n, int):
                return n
        except Exception:
            pass
        return -1

    # --- Windows ANSI Enable ---
    @staticmethod
    def enable_windows_ansi() -> bool:
        if platform.system() != "Windows":
            return False

        try:
            kernel32 = ctypes.windll.kernel32
            handle = kernel32.GetStdHandle(-11)  # STD_OUTPUT_HANDLE
            if handle in (0, -1):
                return False

            mode = ctypes.c_uint()
            if not kernel32.GetConsoleMode(handle, ctypes.byref(mode)):
                return False

            ENABLE_VIRTUAL_TERMINAL_PROCESSING = 0x0004
            new_mode = mode.value | ENABLE_VIRTUAL_TERMINAL_PROCESSING
            if new_mode != mode.value:
                if not kernel32.SetConsoleMode(handle, new_mode):
                    return False
            return True
        except Exception:
            return False

    # --- Core detection logic ---
    @classmethod
    def detect_color_support(cls, force: str | None = None) -> str:
        if force in (
            ColorSupport.TRUECOLOR,
            ColorSupport.COLOR_256,
            ColorSupport.BASIC,
            ColorSupport.NONE,
        ):
            return force

        if not sys.stdout.isatty():
            return ColorSupport.NONE

        if cls._check_env_truecolor():
            return ColorSupport.TRUECOLOR

        term = (os.getenv("TERM") or "").lower()
        if "256color" in term:
            return ColorSupport.COLOR_256
        if "color" in term:
            return ColorSupport.BASIC

        colors = cls._curses_colors()
        if colors >= 16777216:
            return ColorSupport.TRUECOLOR
        if colors >= 256:
            return ColorSupport.COLOR_256
        if colors >= 8:
            return ColorSupport.BASIC

        if platform.system() == "Windows":
            if cls.enable_windows_ansi():
                if cls._check_env_truecolor() or sys.getwindowsversion().major >= 10:
                    return ColorSupport.TRUECOLOR
                return ColorSupport.BASIC
            return ColorSupport.NONE

        return ColorSupport.BASIC


class Colors:
    """Handler untuk color schemes dengan berbagai format output."""

    def __init__(self, color_type='ansi', show_background=False):
        self.color_type = color_type
        self.show_background = show_background

    def rich_color(self, show_background=False):
        """Mengembalikan color scheme dalam format Rich library."""
        if show_background:
            COLORS = {
                'debug': "#000000 on #FFAA00",
                'info': "#000000 on #00FF00",
                'warning': "black on #FFFF00",
                'error': "white on red",
                'critical': "bright_white on #0000FF",
                'fatal': "blue on #FF557F",
                'emergency': "bright_white on #AA00FF",
                'alert': "bright_white on #005500",
                'notice': "black on #00FFFF",
                'reset': '',
            }
        else:
            COLORS = {
                'debug': "#FFAA00",
                'info': "#00FF00",
                'warning': "#FFFF00",
                'error': "red",
                'critical': "#0000FF",
                'fatal': "#FF557F",
                'emergency': "#AA00FF",
                'alert': "#005500",
                'notice': "#00FFFF",
                'reset': '',
            }
        return COLORS

    def check(self):
        """Deteksi dan kembalikan color scheme sesuai terminal support."""
        COLORS = {}
        mode = Check()
        
        if mode == ColorSupport.TRUECOLOR:
            if self.color_type == 'ansi':
                if self.show_background:
                    COLORS = SafeDict({
                        'debug': "\x1b[38;2;0;0;0;48;2;255;170;0m",        # #000000 on #FFAA00
                        'info': "\x1b[38;2;0;0;0;48;2;0;255;0m",           # #000000 on #00FF00
                        'warning': "\x1b[38;2;0;0;0;48;2;255;255;0m",      # black on #FFFF00
                        # 'error': "\x1b[38;2;255;255;255;48;2;255;0;0m",    # white on red (RGB 24-bit) (Bugs)
                        'error': "\x1b[97;41m",                            # white on red
                        'critical': "\x1b[38;2;255;255;255;48;2;0;0;255m", # bright_white on #0000FF
                        'fatal': "\x1b[38;2;0;0;255;48;2;255;85;127m",     # blue on #FF557F
                        'emergency': "\x1b[38;2;255;255;255;48;2;170;0;255m", # bright_white on #AA00FF
                        'alert': "\x1b[38;2;255;255;255;48;2;0;85;0m",     # bright_white on #005500
                        'notice': "\x1b[38;2;0;0;0;48;2;0;255;255m",       # black on #00FFFF
                        'reset': "\x1b[0m"
                    })
                else:
                    COLORS = SafeDict({
                        'debug': "\x1b[38;2;255;170;0m",        # #FFAA00
                        'info': "\x1b[38;2;0;255;0m",           # #00FF00
                        'warning': "\x1b[38;2;255;255;0m",      # #FFFF00
                        'error': "\x1b[38;2;255;0;0m",          # red
                        'critical': "\x1b[38;2;0;0;255m",       # #0000FF
                        'fatal': "\x1b[38;2;255;85;127m",       # #FF557F
                        'emergency': "\x1b[38;2;170;0;255m",    # #AA00FF
                        'alert': "\x1b[38;2;0;85;0m",           # #005500
                        'notice': "\x1b[38;2;0;255;255m",       # #00FFFF
                        'reset': "\x1b[0m"
                    })
            elif self.color_type == 'rich':
                COLORS = self.rich_color(self.show_background)
                
        elif mode == ColorSupport.COLOR_256:
            if self.color_type == 'ansi':
                if self.show_background:
                    COLORS = SafeDict({
                        'debug': "\x1b[30;48;5;214m",      # black on orange
                        'info': "\x1b[30;48;5;46m",        # black on bright green
                        'warning': "\x1b[30;48;5;226m",    # black on yellow
                        'error': "\x1b[97;41m",            # white on red
                        'critical': "\x1b[97;44m",         # white on blue
                        'fatal': "\x1b[21;48;5;204m",      # blue on pink
                        'emergency': "\x1b[97;48;5;129m",  # white on purple
                        'alert': "\x1b[97;48;5;22m",       # white on dark green
                        'notice': "\x1b[30;48;5;51m",      # black on cyan
                        'reset': "\x1b[0m"
                    })
                else:
                    COLORS = SafeDict({
                        'debug': "\x1b[38;5;214m",      # orange
                        'info': "\x1b[38;5;46m",        # bright green
                        'warning': "\x1b[38;5;226m",    # yellow
                        'error': "\x1b[91m",            # red
                        'critical': "\x1b[38;5;21m",    # blue
                        'fatal': "\x1b[38;5;204m",      # pink
                        'emergency': "\x1b[38;5;129m",  # purple
                        'alert': "\x1b[38;5;22m",       # dark green
                        'notice': "\x1b[38;5;51m",      # cyan
                        'reset': "\x1b[0m"
                    })
            elif self.color_type == 'rich':
                COLORS = self.rich_color(self.show_background)
                
        elif mode == ColorSupport.BASIC:
            if self.color_type == 'ansi':
                if self.show_background:
                    COLORS = SafeDict({
                        'debug': "\x1b[30;43m",      # black on yellow
                        'info': "\x1b[30;42m",       # black on green
                        'warning': "\x1b[30;43m",    # black on yellow
                        'error': "\x1b[97;41m",      # white on red
                        'critical': "\x1b[97;44m",   # white on blue
                        'fatal': "\x1b[97;45m",      # white on magenta
                        'emergency': "\x1b[97;45m",  # white on magenta
                        'alert': "\x1b[97;42m",      # white on green
                        'notice': "\x1b[30;46m",     # black on cyan
                        'reset': "\x1b[0m"
                    })
                else:
                    COLORS = SafeDict({
                        'debug': "\x1b[33m",      # yellow
                        'info': "\x1b[32m",       # green
                        'warning': "\x1b[33m",    # yellow
                        'error': "\x1b[31m",      # red
                        'critical': "\x1b[34m",   # blue
                        'fatal': "\x1b[35m",      # magenta
                        'emergency': "\x1b[35m",  # magenta
                        'alert': "\x1b[32m",      # green
                        'notice': "\x1b[36m",     # cyan
                        'reset': "\x1b[0m"
                    })
            elif self.color_type == 'rich':
                # Untuk basic mode, tetap gunakan rich_color format
                COLORS = self.rich_color(self.show_background)
                
        elif mode == ColorSupport.NONE:
            COLORS = SafeDict({
                'debug': '',
                'info': '',
                'warning': '',
                'error': '',
                'critical': '',
                'fatal': '',
                'emergency': '',
                'alert': '',
                'notice': '',
                'reset': ''
            })
        
        return COLORS


# Contoh penggunaan
if __name__ == "__main__":
    colors_ansi = Colors(color_type='ansi', show_background=False).check()
    print(f"colors_ansi: {colors_ansi}")
    # # Test ANSI colors
    # print("=== Testing ANSI Colors ===")
    # colors_ansi = Colors(color_type='ansi', show_background=False)
    # ansi_scheme = colors_ansi.check()
    
    # for level, code in ansi_scheme.items():
    #     if level != 'reset':
    #         print(f"{code}{level.upper()}: This is a test message{ansi_scheme['reset']}")
    
    # print("\n=== Testing ANSI Colors with Background ===")
    # colors_ansi_bg = Colors(color_type='ansi', show_background=True)
    # ansi_bg_scheme = colors_ansi_bg.check()
    
    # for level, code in ansi_bg_scheme.items():
    #     if level != 'reset':
    #         print(f"{code}{level.upper()}: This is a test message{ansi_bg_scheme['reset']}")
    
    # # Test Rich colors (untuk digunakan dengan Rich library)
    # print("\n=== Testing Rich Color Format ===")
    # colors_rich = Colors(color_type='rich', show_background=False)
    # rich_scheme = colors_rich.check()
    
    # for level, style in rich_scheme.items():
    #     if level != 'reset':
    #         print(f"{level.upper()}: {style}")
    
    # # Deteksi mode terminal
    # print(f"\n=== Terminal Color Support: {Check()} ===")


#!/usr/bin/env python3
"""
color_support.py
----------------
Robust cross-platform terminal color detection for Python applications.

Detects if the current terminal supports:
 - truecolor (24-bit RGB)
 - 256 colors (8-bit)
 - basic ANSI (16 colors)
 - none (no color / redirected output)

Compatible with:
 - Linux, macOS, *BSD, and other UNIX-like systems
 - Windows 10+ (CMD, PowerShell, Windows Terminal)
"""

import os
import sys
import platform
import curses
import ctypes


__all__ = ["ColorSupport", "Check"]


class ColorSupport:
    TRUECOLOR = "truecolor"
    COLOR_256 = "256color"
    BASIC = "basic"
    NONE = "none"


class Check:
    """Auto-detect terminal color support across all major OS."""

    def __new__(cls, force: str | None = None):
        """Return detected color mode immediately (not an instance)."""
        return cls.detect_color_support(force)

    # --- Environment checks ---
    @staticmethod
    def _check_env_truecolor() -> bool:
        colorterm = (os.getenv("COLORTERM") or "").lower()
        if "truecolor" in colorterm or "24bit" in colorterm:
            return True
        if os.getenv("WT_SESSION"):  # Windows Terminal
            return True
        return False

    # --- curses terminfo (Unix-like only) ---
    @staticmethod
    def _curses_colors() -> int:
        try:
            curses.setupterm()
            n = curses.tigetnum("colors")
            if isinstance(n, int):
                return n
        except Exception:
            pass
        return -1

    # --- Windows ANSI Enable ---
    @staticmethod
    def enable_windows_ansi() -> bool:
        if platform.system() != "Windows":
            return False

        try:
            kernel32 = ctypes.windll.kernel32
            handle = kernel32.GetStdHandle(-11)  # STD_OUTPUT_HANDLE
            if handle in (0, -1):
                return False

            mode = ctypes.c_uint()
            if not kernel32.GetConsoleMode(handle, ctypes.byref(mode)):
                return False

            ENABLE_VIRTUAL_TERMINAL_PROCESSING = 0x0004
            new_mode = mode.value | ENABLE_VIRTUAL_TERMINAL_PROCESSING
            if new_mode != mode.value:
                if not kernel32.SetConsoleMode(handle, new_mode):
                    return False
            return True
        except Exception:
            return False

    # --- Core detection logic ---
    @classmethod
    def detect_color_support(cls, force: str | None = None) -> str:
        if force in (
            ColorSupport.TRUECOLOR,
            ColorSupport.COLOR_256,
            ColorSupport.BASIC,
            ColorSupport.NONE,
        ):
            return force

        if not sys.stdout.isatty():
            return ColorSupport.NONE

        if cls._check_env_truecolor():
            return ColorSupport.TRUECOLOR

        term = (os.getenv("TERM") or "").lower()
        if "256color" in term:
            return ColorSupport.COLOR_256
        if "color" in term:
            return ColorSupport.BASIC

        colors = cls._curses_colors()
        if colors >= 16777216:
            return ColorSupport.TRUECOLOR
        if colors >= 256:
            return ColorSupport.COLOR_256
        if colors >= 8:
            return ColorSupport.BASIC

        if platform.system() == "Windows":
            if cls.enable_windows_ansi():
                if cls._check_env_truecolor() or sys.getwindowsversion().major >= 10:
                    return ColorSupport.TRUECOLOR
                return ColorSupport.BASIC
            return ColorSupport.NONE

        return ColorSupport.BASIC


# --- Example usage ---
if __name__ == "__main__":
    mode = Check()

    if mode == ColorSupport.TRUECOLOR:
        print("24-bit color detected 🎨")
    elif mode == ColorSupport.COLOR_256:
        print("256 colors supported 🟢")
    elif mode == ColorSupport.BASIC:
        print("Basic ANSI colors ⚪")
    else:
        print("No color support ❌")
